@@ -15,3 +15,6 @@ from .test_summaries import *
 from .test_withmodel import *
 from .test_ok import *
 from .test_history import *
+from .test_spectra import *
+from .test_remove_trends import *
+from .test_time import *
