@@ -28,3 +28,15 @@ def test_normalize(plot=False):
             if plot:
                 r.imshow_quantities(maxcol=4)
     plt.close("all")
+
+
+def test_is_probably_normalized():
+    f = [2] * u.W / u.m**2
+    kw = dict(star_flux=f, R=10, dt=10 * u.minute)
+    assert SimulatedRainbow(**kw)._is_probably_normalized() == False
+    assert SimulatedRainbow(**kw).normalize()._is_probably_normalized() == True
+    assert SimulatedRainbow(**kw).inject_noise()._is_probably_normalized() == False
+    assert (
+        SimulatedRainbow(**kw).inject_noise().normalize()._is_probably_normalized()
+        == True
+    )
